class Dex:
    pancake = 'pancakeswap'
    pancake_v2 = 'pancakeswap-amm'
    pancake_v3 = 'pancakeswap-v3'
    sushi = 'sushi'
    sushi_v2 = 'sushiswap'
    sushi_v3 = 'sushiswap-v3'
    uniswap_v2 = 'uniswap-v2'
    uniswap_v3 = 'uniswap-v3'
    spooky_v2 = 'spookyswap'
    quickswap_v2 = 'quickswap-dex'
    quickswap_v3 = 'quickswap-v3'
